@@ -76,13 +76,14 @@ class ClickReview(object):
     # framework_allowed_peer_hooks = ["apparmor-policy"]
     framework_allowed_peer_hooks = []
     service_allowed_peer_hooks = ["bin-path",
-                                  "systemd",
+                                  "snappy-systemd",
                                   ]
 
     def __init__(self, fn, review_type, peer_hooks=None):
         self.click_package = fn
         self._check_path_exists()
-        if not self.click_package.endswith(".click"):
+        if not self.click_package.endswith(".click") and \
+                not self.click_package.endswith(".snap"):
             if self.click_package.endswith(".deb"):
                 error("filename does not end with '.click', but '.deb' "
                       "instead. See http://askubuntu.com/a/485544/94326 for "
@@ -203,6 +204,8 @@ class ClickReview(object):
         optional = ["title", "description", "maintainer", "architecture",
                     "installed-size", "icon"]
 
+        snappy_optional = ["ports"]
+
         for f in optional:
             if f in self.manifest:
                 if f != "architecture" and \
@@ -232,7 +235,7 @@ class ClickReview(object):
                 error("manifest malformed: hooks/%s is empty:\n%s" % (app, mp))
 
         for k in sorted(self.manifest):
-            if k not in required + optional + ['hooks']:
+            if k not in required + optional + snappy_optional + ['hooks']:
                 # click supports local extensions via 'x-...', ignore those
                 # here but report in lint
                 if k.startswith('x-'):
