@@ -93,7 +93,7 @@ class ClickReviewLint(ClickReview):
                             'pay-ui',
                             'push-helper',
                             'scope',
-                            'systemd',
+                            'snappy-systemd',
                             'urls']
 
         self.redflagged_hooks = ['framework',
@@ -547,74 +547,6 @@ exit 1
             return
         self._add_result(t, n, s)
 
-        t = 'info'
-        n = 'maintainer_domain'
-        s = 'OK'
-        manual_review = False
-        defaults = ('com.ubuntu.developer.', 'net.launchpad.')
-
-        # Some domains give out email addresses in their toplevel namespace
-        # (eg @ubuntu.com is used by Ubuntu members). Anything in these in
-        # domains should show a warning (for now)
-        special_domains = ('com.ubuntu', 'com.facebook', 'com.yahoo')
-
-        if self.click_pkgname.startswith(defaults):
-            # com.ubuntu.developer is Ubuntu's appstore-- people can use their
-            # own addresses
-            s = "OK (package domain=%s)" % str(defaults)
-        else:
-            domain_rev = self.email.partition('@')[2].split('.')
-            domain_rev.reverse()
-
-            pkg_domain_rev = self.click_pkgname.split('.')
-            if len(domain_rev) < 2:  # don't impersonate .com
-                t = 'error'
-                s = "(EMAIL NEEDS HUMAN REVIEW) email domain too short: '%s'" \
-                    % self.email
-                manual_review = True
-            # also '=' to leave room for app name
-            elif len(domain_rev) >= len(pkg_domain_rev):
-                # Core apps have a long email, domain, but that's all right
-                if self.is_core_app:
-                    t = 'info'
-                    s = "OK (email '%s' long, but special case of core apps " \
-                        "'com.ubuntu.*')" % self.email
-                elif self.email == "ubuntu-devel-discuss@lists.ubuntu.com":
-                    t = 'info'
-                    s = "OK (email '%s' long, but special case" % self.email
-                else:
-                    t = 'error'
-                    s = ("(EMAIL NEEDS HUMAN REVIEW) email domain too long "
-                         "'%s' for app name '%s'" % (self.email,
-                                                     ".".join(pkg_domain_rev)))
-                    manual_review = True
-            elif domain_rev == pkg_domain_rev[:len(domain_rev)]:
-                is_special = False
-                for special in special_domains:
-                    if self.click_pkgname.startswith(special + '.'):
-                        is_special = True
-                        break
-                if is_special:
-                    t = 'warn'
-                    s = "email=%s matches special domain=%s" % (self.email,
-                                                                ".".join(pkg_domain_rev))
-                else:
-                    s = "OK (email=%s, package domain=%s)" % (self.email,
-                                                              ".".join(pkg_domain_rev))
-            elif self.is_core_scope:
-                t = 'info'
-                s = "OK ('com.ubuntu.scopes' uses '%s' as email)" % self.email
-            elif self.is_core_snappy:
-                t = 'info'
-                s = "OK ('com.ubuntu.snappy' uses '%s' as email)" % self.email
-            else:
-                t = 'error'
-                s = "email=%s does not match package domain=%s " \
-                    "(Your email domain needs to match the reverse package " \
-                    "namespace.)" % (self.email,
-                                     ".".join(pkg_domain_rev))
-        self._add_result(t, n, s, manual_review=manual_review)
-
     def check_title(self):
         '''Check title()'''
         t = 'info'
@@ -722,17 +654,23 @@ exit 1
                 os.path.basename(self.click_package)
         self._add_result(t, n, s)
 
-        #  handle $pkgname.click
-        pkgname = tmp[0].partition('\.click')[0]
+        #  handle $pkgname.click or $pkgname.snap
+        if tmp[0].endswith('.snap'):
+            pkgname = tmp[0].partition('.snap')[0]
+        else:
+            pkgname = tmp[0].partition('.click')[0]
         t = 'info'
         n = 'package_filename_pkgname_match'
         s = 'OK'
         l = None
         if pkgname != self.click_pkgname:
-            t = 'error'
-            s = "'%s' != '%s' from DEBIAN/control" % (pkgname,
-                                                      self.click_pkgname)
-            l = 'http://askubuntu.com/questions/417361/what-does-lint-package-filename-pkgname-match-mean'
+            if pkgname.startswith('com.ubuntu.snappy.'):
+                s = "OK (store snappy workaround)"
+            else:
+                t = 'error'
+                s = "'%s' != '%s' from DEBIAN/control" % (pkgname,
+                                                          self.click_pkgname)
+                l = 'http://askubuntu.com/questions/417361/what-does-lint-package-filename-pkgname-match-mean'
         self._add_result(t, n, s, l)
 
         # check if namespaces matches with filename
@@ -753,8 +691,11 @@ exit 1
         s = 'OK'
         l = None
         if len(tmp) >= 2:
-            #  handle $pkgname_$version.click
-            version = tmp[1].partition('.click')[0]
+            #  handle $pkgname_$version.click or $pkgname_$version.snap
+            if tmp[0].endswith('.snap'):
+                version = tmp[1].partition('.snap')[0]
+            else:
+                version = tmp[1].partition('.click')[0]
             if version != self.click_version:
                 t = 'error'
                 s = "'%s' != '%s' from DEBIAN/control" % (version,
@@ -770,7 +711,10 @@ exit 1
         n = 'package_filename_arch_valid'
         s = 'OK'
         if len(tmp) >= 3:
-            arch = tmp[2].partition('.click')[0]
+            if tmp[0].endswith('.snap'):
+                arch = tmp[2].partition('.snap')[0]
+            else:
+                arch = tmp[2].partition('.click')[0]
             if arch == "unknown":
                 # short-circuit here since the appstore doesn't determine
                 # the version yet
@@ -791,7 +735,10 @@ exit 1
         n = 'package_filename_arch_match'
         s = 'OK'
         if len(tmp) >= 3:
-            arch = tmp[2].partition('.click')[0]
+            if tmp[0].endswith('.snap'):
+                arch = tmp[2].partition('.snap')[0]
+            else:
+                arch = tmp[2].partition('.click')[0]
             if arch != self.click_arch:
                 t = 'error'
                 s = "'%s' != '%s' from DEBIAN/control" % (arch,
