@@ -82,8 +82,9 @@ class ClickReviewSecurity(ClickReview):
         self.allowed_network_scope_policy_groups = ['accounts', 'networking']
 
         self.redflag_templates = ['unconfined']
-        self.extraneous_templates = ['ubuntu-sdk',
-                                     'default']
+        # TODO: how to deal with other vendors
+        self.extraneous_ubuntu_templates = ['ubuntu-sdk',
+                                            'default']
 
         # framework policy is based on major framework version. In 13.10, there
         # was only 'ubuntu-sdk-13.10', but in 14.04, there will be several,
@@ -293,10 +294,12 @@ class ClickReviewSecurity(ClickReview):
             t = 'info'
             n = 'policy_version_is_highest (%s, %s)' % (str(highest), f)
             s = "OK"
-            if float(version) != highest:
+            l = None
+            if float(m['policy_version']) != highest:
                 t = 'info'
-                s = '%s != %s' % (version, str(highest))
-            self._add_result(t, n, s)
+                l = 'http://askubuntu.com/q/562116/94326'
+                s = '%s != %s' % (str(m['policy_version']), str(highest))
+            self._add_result(t, n, s, l)
 
             t = 'info'
             n = 'policy_version_matches_framework (%s)' % (f)
@@ -307,10 +310,10 @@ class ClickReviewSecurity(ClickReview):
                 if not self.manifest['framework'].startswith(name):
                     continue
                 found_major = True
-                if version != str(data['policy_version']):
+                if m['policy_version'] != data['policy_version']:
                     t = 'error'
-                    s = '%s != %s (%s)' % (version,
-                                           str(data['policy_version']),
+                    s = '%s != %s (%s)' % (str(m['policy_version']),
+                                           data['policy_version'],
                                            self.manifest['framework'])
             if not found_major:
                 t = 'error'
@@ -343,7 +346,8 @@ class ClickReviewSecurity(ClickReview):
                 t = 'error'
                 s = "(MANUAL REVIEW) '%s' not allowed" % m['template']
                 manual_review = True
-            elif m['template'] in self.extraneous_templates:
+            elif ('policy_vendor' not in m or m['policy_vendor'] == 'ubuntu') \
+                    and m['template'] in self.extraneous_ubuntu_templates:
                 t = 'warn'
                 s = "No need to specify '%s' template" % m['template']
             self._add_result(t, n, s, manual_review=manual_review)
@@ -553,6 +557,7 @@ class ClickReviewSecurity(ClickReview):
                     t = 'info'
                     n = 'policy_groups_safe_%s (%s)' % (app, i)
                     s = 'OK'
+                    l = None
                     manual_review = False
 
                     aa_type = self._get_policy_group_type(vendor, version, i)
@@ -564,12 +569,14 @@ class ClickReviewSecurity(ClickReview):
                         t = 'error'
                         s = "(MANUAL REVIEW) %s policy group " % aa_type + \
                             "'%s': vetted applications only" % (i)
+                        if i == "debug":
+                            l = 'http://askubuntu.com/a/562123/94326'
                         manual_review = True
                     elif aa_type != "common":
                         t = 'error'
                         s = "policy group '%s' has" % i + \
                             "unknown type '%s'" % (aa_type)
-                    self._add_result(t, n, s, manual_review=manual_review)
+                    self._add_result(t, n, s, l, manual_review=manual_review)
 
     def check_ignored(self):
         '''Check ignored fields'''
