@@ -209,11 +209,14 @@ class TestClickReviewSecurity(cr_tests.TestClickReview):
             {"text": "Invalid framework 'nonexistent'"}
         self.check_results(report, expected=expected)
 
-    def _test_check_policy_version_framework_with_overrides(self, overrides):
+    def test_check_policy_version_framework_with_overrides(self):
         '''Test check_policy_version() - override framework (nonexistent)'''
         self.set_test_manifest("framework", "nonexistent")
         self.set_test_security_manifest(self.default_appname,
                                         "policy_version", 1.3)
+        overrides = {'framework': {'nonexistent': {'state': 'available',
+                                                   'policy_vendor': 'ubuntu',
+                                                   'policy_version': 1.3}}}
         c = ClickReviewSecurity(self.test_name, overrides=overrides)
         c.check_policy_version()
         report = c.click_report
@@ -221,26 +224,14 @@ class TestClickReviewSecurity(cr_tests.TestClickReview):
         expected_counts = {'info': 3, 'warn': 0, 'error': 0}
         self.check_results(report, expected_counts)
 
-    def test_check_policy_version_framework_overrides_version_float(self):
-        overrides = {'framework': {'nonexistent': {'state': 'available',
-                                                   'policy_vendor': 'ubuntu',
-                                                   'policy_version': 1.3}}}
-        self._test_check_policy_version_framework_with_overrides(overrides)
-
-    def test_check_policy_version_framework_overrides_version_string(self):
-        overrides = {'framework': {'nonexistent': {'state': 'available',
-                                                   'policy_vendor': 'ubuntu',
-                                                   'policy_version': '1.3'}}}
-        self._test_check_policy_version_framework_with_overrides(overrides)
-
     def test_check_policy_version_framework_with_malformed_overrides(self):
         '''Test check_policy_version() - incorrectly override framework'''
         self.set_test_manifest("framework", "nonexistent")
         self.set_test_security_manifest(self.default_appname,
-                                        "policy_version", 1.3)
+                                        "policy_version", 999999999.3)
         overrides = {'nonexistent': {'state': 'available',
                                      'policy_vendor': 'ubuntu',
-                                     'policy_version': 1.3}}
+                                     'policy_version': 999999999.3}}
         c = ClickReviewSecurity(self.test_name, overrides=overrides)
         c.check_policy_version()
         report = c.click_report
@@ -318,6 +309,56 @@ class TestClickReviewSecurity(cr_tests.TestClickReview):
             {"text": "No need to specify 'ubuntu-sdk' template"}
         self.check_results(report, expected=expected)
 
+    def test_check_template_default(self):
+        '''Test check_template() - default specified with no vendor'''
+        c = ClickReviewSecurity(self.test_name)
+        self.set_test_security_manifest(self.default_appname,
+                                        "template", "default")
+        c.check_template()
+        report = c.click_report
+        expected_counts = {'info': None, 'warn': 1, 'error': 0}
+        self.check_results(report, expected_counts)
+
+    def test_check_template_default_with_ubuntu(self):
+        '''Test check_template() - default specified with ubuntu vendor'''
+        c = ClickReviewSecurity(self.test_name)
+        self.set_test_security_manifest(self.default_appname,
+                                        "template", "default")
+        self.set_test_security_manifest(self.default_appname,
+                                        "policy_vendor", "ubuntu")
+        c.check_template()
+        report = c.click_report
+        expected_counts = {'info': None, 'warn': 1, 'error': 0}
+        self.check_results(report, expected_counts)
+
+    def test_check_template_default_with_snappy(self):
+        '''Test check_template() - default specified with ubuntu-snappy vendor'''
+        c = ClickReviewSecurity(self.test_name)
+        self.set_test_security_manifest(self.default_appname,
+                                        "template", "default")
+        self.set_test_security_manifest(self.default_appname,
+                                        "policy_vendor", "ubuntu-snappy")
+        self.set_test_security_manifest(self.default_appname,
+                                        "policy_version", 1.3)
+        c.check_template()
+        report = c.click_report
+        expected_counts = {'info': None, 'warn': 0, 'error': 0}
+        self.check_results(report, expected_counts)
+
+    def test_check_template_nonexistent_with_snappy(self):
+        '''Test check_template() - nonexistent with ubuntu-snappy vendor'''
+        c = ClickReviewSecurity(self.test_name)
+        self.set_test_security_manifest(self.default_appname,
+                                        "template", "nonexistent")
+        self.set_test_security_manifest(self.default_appname,
+                                        "policy_vendor", "ubuntu-snappy")
+        self.set_test_security_manifest(self.default_appname,
+                                        "policy_version", 1.3)
+        c.check_template()
+        report = c.click_report
+        expected_counts = {'info': None, 'warn': 0, 'error': 1}
+        self.check_results(report, expected_counts)
+
     def test_check_template_webapp(self):
         '''Test check_template() - webapp'''
         c = ClickReviewSecurity(self.test_name)
